@@ -1,3 +1,4 @@
+# TODO: Deprecate settings_validation in favor of using app_settings to run necessary validations
 import pkg_resources
 from django.apps import apps
 from django.conf import settings
@@ -26,12 +27,11 @@ def required_dependencies(app_configs, **kwargs):
 
 
 def required_installed_apps(app_configs, **kwargs):
-    errors = []
-    for app in REQUIRED_INSTALLED_APPS:
-        if not apps.is_installed(app):
-            errors.append(Error(f"{app} is required in INSTALLED_APPS"))
-
-    return errors
+    return [
+        Error(f"{app} is required in INSTALLED_APPS")
+        for app in REQUIRED_INSTALLED_APPS
+        if not apps.is_installed(app)
+    ]
 
 
 def required_settings(app_configs, **kwargs):
